@@ -148,6 +148,9 @@ void TodoTest::testAssign()
     IncidenceBase *todo2 = new Todo;
     *todo2 = todo1;     // Use IncidenceBase's virtual assignment.
     QVERIFY(todo1 == *todo2);
+
+    // release todo2
+    delete todo2;
 }
 
 void TodoTest::testSetCompletedWithDate()
@@ -533,3 +536,5 @@ void TodoTest::testDtDueChange()
     todo.setDtDue(QDateTime(date, time, Qt::LocalTime));
     QCOMPARE(todo.dirtyFields(), QSet<IncidenceBase::Field>{IncidenceBase::FieldDtDue});
 }
+
+#include "moc_testtodo.cpp"
